==> Ambidexterity-0.3.1%2B1.21.5-Fabric-sources.jar: eva/ambidexterity/AmbidexterityClient.java <==
package eva.ambidexterity;

import eva.ambidexterity.access.InventoryAccess;
import eva.ambidexterity.config.AmbidexterityConfig;
import eva.ambidexterity.init.ParticleInit;
import eva.ambidexterity.network.BalancePacket;
import eva.ambidexterity.network.HotHandPacket;
import eva.scrolltweaks.events.PlayScrollCallback;
import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.fabric.api.client.keybinding.v1.KeyBindingHelper;
import net.fabricmc.fabric.api.client.networking.v1.ClientConfigurationConnectionEvents;
import net.fabricmc.fabric.api.client.networking.v1.ClientConfigurationNetworking;
import net.fabricmc.fabric.api.client.networking.v1.ClientPlayConnectionEvents;
import net.fabricmc.fabric.api.client.networking.v1.ClientPlayNetworking;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_304;
import net.minecraft.class_310;
import net.minecraft.class_3675;
import net.minecraft.class_746;
import org.lwjgl.glfw.GLFW;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static eva.ambidexterity.config.AmbidexterityConfig.isInvertWithCrouch;
import static eva.ambidexterity.config.AmbidexterityConfig.isToggleInvert;

public class AmbidexterityClient implements ClientModInitializer {

    public static final String MOD_ID = AmbidexterityMain.MOD_ID + "-client";
    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    public static final class_304 modBind;
    private static boolean toggle = false;

    private static boolean sprindicator = false;
    private static boolean scrollTweaks = false;

    public static boolean sprindicator() {return sprindicator;}
    public static boolean scrollTweaks() {return scrollTweaks;}

    @Override
    public void onInitializeClient() {

        ParticleInit.initClient();

        LOGGER.info("The packets were a nightmare. Appreciate them.");

        sprindicator = FabricLoader.getInstance().isModLoaded("sprintindicator");
        scrollTweaks = FabricLoader.getInstance().isModLoaded("evascrolltweaks") && !FabricLoader.getInstance().getModContainer("evascrolltweaks").get().getMetadata().getVersion().getFriendlyString().equals("0.0.0");


        ClientConfigurationConnectionEvents.INIT.register((handler,client) -> {
            ClientConfigurationNetworking.registerGlobalReceiver(BalancePacket.TYPE, (payload, context) ->
                    context.client().execute(() ->
                            AmbidexterityConfig.onBalanceReceived(payload)));
        });
        ClientPlayConnectionEvents.DISCONNECT.register((handler, client) -> {
            LOGGER.info("Removing server config");
            client.execute(AmbidexterityConfig::disconnect);
        });
        ClientConfigurationConnectionEvents.DISCONNECT.register((handler, client) -> {
            LOGGER.info("Removing server config; failed config!");
            client.execute(AmbidexterityConfig::disconnect);
            ClientConfigurationNetworking.unregisterGlobalReceiver(BalancePacket.TYPE);
        });

        if (scrollTweaks) {
            LOGGER.info("Eva's Scroll Tweaks Loaded!");
            PlayScrollCallback.SCROLL_EVENT.register((vector) -> {
                assert class_310.method_1551().field_1724 != null;
                ((InventoryAccess) class_310.method_1551().field_1724.method_31548()).handleSideScroll(vector.x());
                return false;
            });
        } else {
            LOGGER.info("Evas's Scroll Tweaks Not Loaded!");
        }
    }

    public static boolean isInvertedInclToggle() {
        if (isToggleInvert()) return toggle;
        return isInvertedNoToggle();
    }

    public static boolean isInvertedNoToggle() {
        if (class_310.method_1551().field_1724 != null && (isInvertWithCrouch() || modBind.method_1415()) && class_310.method_1551().field_1724.method_18276()) return true;
        return modBind.method_1434();
    }

    public static void handleTicker() {
        class_746 player = class_310.method_1551().field_1724;
        if (player == null) return;
        if (
                (isToggleInvert() && modBind.method_1436())
                        || (
                        !isToggleInvert() &&
                                (
                                        toggle != modBind.method_1434()
                                                || (isInvertWithCrouch() && toggle != player.method_18276())
                                )
                )
        ) {
            toggle = !toggle;
            ClientPlayNetworking.send(new HotHandPacket(toggle));
        }
    }

    static {
        modBind = KeyBindingHelper.registerKeyBinding(
                new class_304(
                        "Ambidextrous Invert Key",
                        class_3675.class_307.field_1668,
                        GLFW.GLFW_KEY_UNKNOWN,
                        class_304.field_32139
                )
        );
    }
}

==> Ambidexterity-0.3.2%2B1.21.4-Fabric-sources.jar: eva/ambidexterity/AmbidexterityClient.java <==
package eva.ambidexterity;

import eva.ambidexterity.access.InventoryAccess;
import eva.ambidexterity.config.AmbidexterityConfig;
import eva.ambidexterity.init.ParticleInit;
import eva.ambidexterity.network.BalancePacket;
import eva.ambidexterity.network.HotHandPacket;
import eva.scrolltweaks.events.PlayScrollCallback;
import net.fabricmc.api.ClientModInitializer;
import net.fabricmc.fabric.api.client.keybinding.v1.KeyBindingHelper;
import net.fabricmc.fabric.api.client.networking.v1.ClientConfigurationConnectionEvents;
import net.fabricmc.fabric.api.client.networking.v1.ClientConfigurationNetworking;
import net.fabricmc.fabric.api.client.networking.v1.ClientPlayConnectionEvents;
import net.fabricmc.fabric.api.client.networking.v1.ClientPlayNetworking;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_304;
import net.minecraft.class_310;
import net.minecraft.class_3675;
import net.minecraft.class_746;
import org.lwjgl.glfw.GLFW;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static eva.ambidexterity.config.AmbidexterityConfig.isInvertWithCrouch;
import static eva.ambidexterity.config.AmbidexterityConfig.isToggleInvert;

public class AmbidexterityClient implements ClientModInitializer {

    public static final String MOD_ID = AmbidexterityMain.MOD_ID + "-client";
    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    public static final class_304 modBind;
    private static boolean toggle = false;

    private static boolean sprindicator = false;
    private static boolean scrollTweaks = false;

    public static boolean sprindicator() {return sprindicator;}
    public static boolean scrollTweaks() {return scrollTweaks;}

    @Override
    public void onInitializeClient() {

        ParticleInit.initClient();

        LOGGER.info("The packets were a nightmare. Appreciate them.");

        sprindicator = FabricLoader.getInstance().isModLoaded("sprintindicator");
        scrollTweaks = FabricLoader.getInstance().isModLoaded("evascrolltweaks") && !FabricLoader.getInstance().getModContainer("evascrolltweaks").get().getMetadata().getVersion().getFriendlyString().equals("0.0.0");


        ClientConfigurationConnectionEvents.INIT.register((handler,client) -> {
            ClientConfigurationNetworking.registerGlobalReceiver(BalancePacket.TYPE, (payload, context) ->
                    context.client().execute(() -> {
                            AmbidexterityConfig.onBalanceReceived(payload);
                            LOGGER.info("Balance received!");
                    }));
        });
        ClientPlayConnectionEvents.DISCONNECT.register((handler, client) -> {
            LOGGER.info("Removing server config");
            client.execute(AmbidexterityConfig::disconnect);
        });
        ClientConfigurationConnectionEvents.DISCONNECT.register((handler, client) -> {
            LOGGER.info("Removing server config; failed config!");
            client.execute(AmbidexterityConfig::disconnect);
            ClientConfigurationNetworking.unregisterGlobalReceiver(BalancePacket.TYPE);
        });

        if (scrollTweaks) {
            LOGGER.info("Eva's Scroll Tweaks Loaded!");
            PlayScrollCallback.SCROLL_EVENT.register((vector) -> {
                assert class_310.method_1551().field_1724 != null;
                ((InventoryAccess) class_310.method_1551().field_1724.method_31548()).handleSideScroll(vector.x());
                return false;
            });
        } else {
            LOGGER.info("Evas's Scroll Tweaks Not Loaded!");
        }
    }

    public static boolean isInvertedInclToggle() {
        if (isToggleInvert()) return toggle;
        return isInvertedNoToggle();
    }

    public static boolean isInvertedNoToggle() {
        if (class_310.method_1551().field_1724 != null && (isInvertWithCrouch() || modBind.method_1415()) && class_310.method_1551().field_1724.method_18276()) return true;
        return modBind.method_1434();
    }

    public static void handleTicker() {
        class_746 player = class_310.method_1551().field_1724;
        if (player == null) return;
        if (
                (isToggleInvert() && modBind.method_1436())
                        || (
                        !isToggleInvert() &&
                                (
                                        toggle != modBind.method_1434()
                                                || (isInvertWithCrouch() && toggle != player.method_18276())
                                )
                )
        ) {
            toggle = !toggle;
            ClientPlayNetworking.send(new HotHandPacket(toggle));
        }
    }

    static {
        modBind = KeyBindingHelper.registerKeyBinding(
                new class_304(
                        "Ambidextrous Invert Key",
                        class_3675.class_307.field_1668,
                        GLFW.GLFW_KEY_UNKNOWN,
                        class_304.field_32139
                )
        );
    }
}
